function Z3 = inconvhull(Z1,Z2)

% INCONVHULL --- Returns in Z3 the elements of Z1 that are
%                inside the convex hull of Z2
%
% This function returns the elements of Z1 that lie
% inside the convex hull of Z2. Z1 and Z2 must be matrices,
% each row of which is a point in n-space.

% This file is part of SOSTOOLS - Sum of Squares Toolbox ver 1.00.
%
% Copyright (C) 2002  S. Prajna (1), A. Papachristodoulou (1), P. A. Parrilo (2)
% (1) Control and Dynamical Systems - California Institute of Technology,
%     Pasadena, CA 91125, USA.
% (2) Institut fur Automatik - ETH Zurich, CH-8092 Zurich, Switzerland.
%
% Send feedback to: sostools@cds.caltech.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%

% AP Apr 03 2002

% First, find the convex hull of Z2
monom = Z2;
numpoints = size(monom,1);
Conv = convhulln(monom);
facets = size(Conv,1);
dimensp = size(Conv,2);
% Form the hyperplanes
for i = 1:facets
    vert = [monom(Conv(i,:),:) -ones(dimensp,1)];
    nullvert = null(vert,'r');
    if size(nullvert,2) == 1  
        if nullvert(end) ~=0
            nullvert = nullvert./nullvert(end);
        end
        coeff(:,i) = nullvert(1:end-1);
        cold(i,1) = nullvert(end); 
    end
end
coeff = coeff';
% Discard same hyperplanes (due to convhulln result)
[coeff2cold,Ix,Iy] = unique([coeff cold],'rows');
yind = find(sum(coeff2cold.^2,2)==0);
if ~isempty(yind)
    Ix = [Ix([1:yind-1],1);Ix(yind+1:end,1)];
end
coeff2 = coeff(Ix,:);
Convnew = Conv(Ix,:);
cnew = cold(Ix);
facetsnew = size(Convnew,1);

% Make inequalities out of them by testing a point not on the hyperplane
for fac = 1:facetsnew
    for ind = 1:numpoints
        matr = find(Convnew(fac,:)==ind);
        tests = coeff2(fac,:)*monom(ind,:)'-cnew(fac);
        if isempty(matr) & tests~=0
            break
        end
    end
    if tests<0
        coeff2(fac,:)=-coeff2(fac,:);
        cnew(fac)=-cnew(fac);
    end
end

% Now return the elements of Z1 that lie in the convexhull of Z2

Z3 = [];
for i = 1:size(Z1,1)
    if isempty(find(coeff2*Z1(i,:)'-cnew<-1e-9))
        Z3 = [Z3; Z1(i,:)];
    end
end