function [Dp] = findderiv(p,i,j)
% FINDDERIV --- Find derivative of a polynomial vector
%
% [derivp] = findderiv(p,i,j)
%
% Given a vector of polynomials p, this function will
% compute the i-th derivative of the polynomials with
% respect to the j-th variable, i.e.,
%           
%          d^i        
% Dp =   -------  p(x)
%        dx_j ^i
%

% This file is part of SOSTOOLS - Sum of Squares Toolbox ver 1.00.
%
% Copyright (C) 2002  S. Prajna (1), A. Papachristodoulou (1), P. A. Parrilo (2)
% (1) Control and Dynamical Systems - California Institute of Technology,
%     Pasadena, CA 91125, USA.
% (2) Institut fur Automatik - ETH Zurich, CH-8092 Zurich, Switzerland.
%
% Send feedback to: sostools@cds.caltech.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%

% 11/30/01 - SP

Dp = p;
for k = 1:i
    for m = 1:size(Dp.F,1)
        Dp.F(m,:) = Dp.F(m,:) .* Dp.Z(:,j)';
    end;
    Dp.Z(:,j) = max(Dp.Z(:,j)-1,0);
end;

% Delete redundant monomials    
I = find(sum(abs(Dp.F),1) > 0);
if length(I)>0
    Dp.F = Dp.F(:,I);
    Dp.Z = Dp.Z(I,:);
else  % If zero polynomial
    Dp.F = Dp.F(:,1)*0;
    Dp.Z = Dp.Z(1,:)*0;
end;
