function sos = sossetobj(sos,symexpr)
% SOSSETOBJ --- Set the objective function of an SOS program. 
%
% SOSP = sossetobj(SOSP,EXPR)
%
% Given a sum of squares program SOSP and a symbolic expression
% EXPR, this function makes EXPR the objective of the sum of
% squares program SOSP, i.e., EXPR will be minimized.
%

% This file is part of SOSTOOLS - Sum of Squares Toolbox ver 1.00.
%
% Copyright (C) 2002  S. Prajna (1), A. Papachristodoulou (1), P. A. Parrilo (2)
% (1) Control and Dynamical Systems - California Institute of Technology,
%     Pasadena, CA 91125, USA.
% (2) Institut fur Automatik - ETH Zurich, CH-8092 Zurich, Switzerland.
%
% Send feedback to: sostools@cds.caltech.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%


% 01/07/02 - SP
% 03/01/02 - SP -- New syntax

% Creating matching table
objvartable = [',',findsym(symexpr),','];
objvartable = objvartable(find(objvartable~=' '));        % 03/25/02
decvartable = [',',sos.decvartable(2:end-1),','];
idxcomma1 = find(objvartable==',');
idxcomma2 = find(decvartable==',');

for i = 1:length(idxcomma1)-1
    j = findstr(decvartable,objvartable(idxcomma1(i):idxcomma1(i+1)));
    if length(j)==0
        error('There is unknown decision variable');
    end;
    j = find(idxcomma2==j);
    idx(i) = j;        % idx contains indices of decision variables
    sos.objective(idx(i)) = double(diff(symexpr,sos.symdecvartable(idx(i))));
    symexpr = simplify(symexpr - sos.objective(idx(i))*sos.symdecvartable(idx(i)));    % Optimize here
end;

if double(symexpr) ~= 0
    error('Not a linear objective function.');
end;
    
